@@ -1,6 +1,10 @@
-#' @title Data check for errors
+#' @title Preliminary data check for errors
 #' @description
-#' Preliminary check of data frame for missing values, wrong format, outliers.
+#' Preliminary check of data frame for missing values, numeric format, outliers.
+#'
+#' Missing items: The number of missing values in each column of the dataset.
+#' Numeric format: The number of non-numeric variables in each column of the dataset.
+#' Outliers: The number of outliers in each column of the dataset.
 #' @usage checkdata(x)
 #' @param x is a data frame
 #' @import stats
@@ -14,13 +18,12 @@
 
 #must be without N/A to run
 
-globalVariables(c("macroKZ"))
 
 checkdata<-
   function (x)
 
   {
-    miss<-sapply(macroKZ, function(x){
+    miss<-sapply(x, function(x){
       sum(is.na(x))})
 
     missing_total=0
@@ -35,14 +38,14 @@ checkdata<-
       count=0
       sdt<-3*sd(x, na.rm=TRUE)
       m<-mean(x)
-      for (x in colnames(macroKZ))
+      for (c in x)
       {
-        if ((x>m+sdt) & (x<m-sdt))
+        if ((c>m+sdt) & (c<m-sdt))
           count<-count+1
         return(count)}
     }
 
-    outlier<-sapply(na.remove(macroKZ), out)
+    outlier<-sapply(na.remove(x), out)
 
     outlier_total=0
     for (i in 1:length(outlier)){
@@ -59,8 +62,8 @@ checkdata<-
     #print
 
     w <- console_width()
-    w1 <- max(nchar(macroKZ))
-    n <- ncol(macroKZ)
+    w1 <- max(nchar(x))
+    n <- ncol(x)
 
     cat(paste("There are", missing_total, "missing items in the dataset."),
         paste("There are", notnum_total, "items in non-numeric format in the dataset."),
